@@ -10,7 +10,9 @@ hotfix.require('twisted', 'filepath_copyTo')
 from zope.interface import implements
 
 from twisted.python import filepath
+from twisted.python.deprecate import deprecated
 from twisted.python.components import registerAdapter
+from twisted.python.versions import Version
 
 from epsilon.extime import Time
 
@@ -915,11 +917,34 @@ class bytes(SQLAttribute):
             raise ConstraintError(self, "str or other byte buffer", pyval)
         return buffer(pyval)
 
+
     def outfilter(self, dbval, oself):
         if dbval is None:
             return None
         return str(dbval)
 
+
+    @deprecated(Version("Axiom", 0, 7, 5))
+    def like(self, *others):
+        return super(SQLAttribute, self).like(*others)
+
+
+    @deprecated(Version("Axiom", 0, 7, 5))
+    def notLike(self, *others):
+        return super(SQLAttribute, self).notLike(*others)
+
+
+    @deprecated(Version("Axiom", 0, 7, 5))
+    def startswith(self, other):
+        return super(SQLAttribute, self).startswith(other)
+
+
+    @deprecated(Version("Axiom", 0, 7, 5))
+    def endswith(self, other):
+        return super(SQLAttribute, self).endswith(other)
+
+
+
 class InvalidPathError(ValueError):
     """
     A path that could not be used with the database was attempted to be used
@@ -1123,7 +1148,12 @@ class reference(integer):
             assert self.whenDeleted is reference.NULLIFY, (
                 "not sure what to do if not...")
             return None
-        if rv.__legacy__:
+        # If the current cached value is a legacy item, we discard it in order
+        # to force another fetch from the database. However, if *this item* is
+        # also a legacy item, then the item referred to may have been created
+        # in an upgrader and not have been stored yet, so we shouldn't discard
+        # it.
+        if rv.__legacy__ and not oself.__legacy__:
             delattr(oself, self.underlying)
             return super(reference, self).__get__(oself, cls)
         return rv
