@@ -104,11 +104,23 @@ class Start(twistd.ServerOptions):
     def getArguments(self, store, args):
         run = store.dbdir.child("run")
         logs = run.child("logs")
-        if "--logfile" not in args and "-l" not in args and "--nodaemon" not in args and "-n" not in args:
+        handleLogfile = True
+        handlePidfile = True
+
+        for arg in args:
+            if arg.startswith("--logfile=") or arg in (
+                "-l", "--logfile", "-n", "--nodaemon"
+            ):
+                handleLogfile = False
+            elif arg.startswith("--pidfile=") or arg == "--pidfile":
+                handlePidfile = False
+
+        if handleLogfile:
             if not logs.exists():
                 logs.makedirs()
             args.extend(["--logfile", logs.child("axiomatic.log").path])
-        if not platform.isWindows() and "--pidfile" not in args:
+
+        if not platform.isWindows() and handlePidfile:
             args.extend(["--pidfile", run.child("axiomatic.pid").path])
         args.extend(["axiomatic-start", "--dbdir", store.dbdir.path])
         return args
@@ -121,11 +133,17 @@ class Start(twistd.ServerOptions):
             # If a reactor is being selected, it must be done before the store
             # is opened, since that may execute arbitrary application code
             # which may in turn install the default reactor.
-            if "--reactor" in args:
-                reactorIndex = args.index("--reactor")
-                shortName = args[reactorIndex + 1]
-                del args[reactorIndex:reactorIndex + 2]
-                self.opt_reactor(shortName)
+            for index, arg in enumerate(args):
+                if arg in ("--reactor", "-r"):
+                    shortName = args[index + 1]
+                    del args[index:index + 2]
+                    self.opt_reactor(shortName)
+                    break
+                elif arg.startswith("--reactor="):
+                    shortName = arg.split("=")[1]
+                    del args[index]
+                    self.opt_reactor(shortName)
+                    break
             sys.argv[1:] = self.getArguments(self.parent.getStore(), args)
             self.run()
 
