@@ -26,31 +26,60 @@ class SubStore(Item):
         """
         Create a new SubStore, allocating a new file space for it.
         """
-        storepath = store.newDirectory(*pathSegments)
-        self = cls(store=store, storepath=storepath)
+        if isinstance(pathSegments, basestring):
+            raise ValueError(
+                'Received %r instead of a sequence' % (pathSegments,))
+        if store.dbdir is None:
+            self = cls(store=store, storepath=None)
+        else:
+            storepath = store.newDirectory(*pathSegments)
+            self = cls(store=store, storepath=storepath)
         self.open()
         self.close()
         return self
 
     createNew = classmethod(createNew)
 
+
     def close(self):
         self.substore.close()
         del self.substore._openSubStore
         del self.substore
 
+
     def open(self, debug=False):
         if hasattr(self, 'substore'):
             return self.substore
         else:
-            s = self.substore = Store(self.storepath.path,
-                                      parent=self.store,
-                                      idInParent=self.storeID,
-                                      debug=debug)
+            s = self.substore = self.createStore(debug)
             s._openSubStore = self # don't fall out of cache as long as the
                                    # store is alive!
             return s
 
+
+    def createStore(self, debug):
+        """
+        Create the actual Store this Substore represents.
+        """
+        if self.storepath is None:
+            self.store._memorySubstores.append(self) # don't fall out of cache
+            if self.store.filesdir is None:
+                filesdir = None
+            else:
+                filesdir = (self.store.filesdir.child("_substore_files")
+                                               .child(str(self.storeID))
+                                               .path)
+            return Store(parent=self.store,
+                         filesdir=filesdir,
+                         idInParent=self.storeID,
+                         debug=debug)
+        else:
+            return Store(self.storepath.path,
+                         parent=self.store,
+                         idInParent=self.storeID,
+                         debug=debug)
+
+
     def __conform__(self, interface):
         """
         I adapt my store object to whatever interface I am adapted to.  This
@@ -62,6 +91,7 @@ class SubStore(Item):
         ifa = interface(self.open(debug=self.store.debug), None)
         return ifa
 
+
     def indirect(self, interface):
         """
         Like __conform__, I adapt my store to whatever interface I am asked to
