@@ -1,4 +1,5 @@
 from twisted.application.service import Service, IService
+from twisted.python import filepath
 
 from twisted.trial import unittest
 
@@ -11,15 +12,14 @@ from axiom.attributes import text, bytes, boolean, inmemory
 
 
 class SubStored(Item):
-
     schemaVersion = 1
     typeName = 'substoredthing'
     a = text()
     b = bytes()
 
 
-class YouCantStartThis(Item, Service):
 
+class YouCantStartThis(Item, Service):
     parent = inmemory()
     running = inmemory()
     name = inmemory()
@@ -29,8 +29,9 @@ class YouCantStartThis(Item, Service):
     def startService(self):
         self.started = True
 
+
+
 class YouShouldStartThis(Item, Service):
-
     parent = inmemory()
     running = inmemory()
     name = inmemory()
@@ -41,17 +42,17 @@ class YouShouldStartThis(Item, Service):
         self.started = True
 
 
+
 class SubStoreTest(unittest.TestCase):
     """
     Test on-disk creation of substores.
     """
-
     def testOneThing(self):
         """
         Ensure that items can be inserted into substores and
         subsequently retrieved.
         """
-        topdb = self.mktemp()
+        topdb = filepath.FilePath(self.mktemp())
         s = Store(topdb)
         ss = SubStore.createNew(s, ['account', 'bob@divmod.com'])
         s2 = ss.open()
@@ -71,6 +72,7 @@ class SubStoreTest(unittest.TestCase):
         self.assertEquals(reopenssd.a, u'hello world')
         self.assertEquals(reopenssd.b, 'what, its text')
 
+
     def test_oneThingMemory(self):
         """
         Ensure that items put into in-memory substores are retrievable.
@@ -112,12 +114,13 @@ class SubStoreTest(unittest.TestCase):
         self.assertEquals(item.a, u'hello world')
         self.assertEquals(item.b, 'what, its text')
 
+
     def test_memorySubstoreFile(self):
         """
         In-memory substores whose stores have file directories should be able
         to create files.
         """
-        filesdir = self.mktemp()
+        filesdir = filepath.FilePath(self.mktemp())
         s = Store(filesdir=filesdir)
         ss = SubStore.createNew(s, ['account', 'bob@divmod.com'])
         s2 = ss.open()
@@ -126,6 +129,20 @@ class SubStoreTest(unittest.TestCase):
         f.close()
         self.assertEqual(open(f.finalpath.path).read(), "yay")
 
+
+    def test_createNewStringPath(self):
+        """
+        Passing a string instead of a sequence of strings to
+        L{SubStore.createNew} results in an exception.
+        """
+        s = Store()
+        e = self.assertRaises(
+            ValueError, SubStore.createNew, s, 'notasequence')
+        self.assertEqual(
+            e.args[0], "Received 'notasequence' instead of a sequence")
+
+
+
 class SubStoreStartupSemantics(unittest.TestCase):
     """
     These tests verify that interactions between store and substore services
@@ -133,12 +150,12 @@ class SubStoreStartupSemantics(unittest.TestCase):
     behavior.  Read the code if you are interested in how to get startup
     notifications from substore items.
     """
-
     def setUp(self):
         """
-        Set up the tests by creating a store and a substore and opening them both.
+        Set up the tests by creating a store and a substore and opening them
+        both.
         """
-        self.topdb = topdb = Store(self.mktemp())
+        self.topdb = topdb = Store(filepath.FilePath(self.mktemp()))
         self.ssitem = ssitem = SubStore.createNew(
             topdb, ["dontstartme", "really"])
         self.ss = ssitem.open()
@@ -146,8 +163,8 @@ class SubStoreStartupSemantics(unittest.TestCase):
 
     def testDontStartNormally(self):
         """
-        Substores' services are not supposed to be started when their parent stores
-        are.
+        Substores' services are not supposed to be started when their parent
+        stores are.
         """
         ss = self.ss
         ycst = YouCantStartThis(store=ss)
@@ -182,4 +199,3 @@ class SubStoreStartupSemantics(unittest.TestCase):
         """
         if self.serviceStarted:
             return IService(self.topdb).stopService()
-
