@@ -239,7 +239,14 @@ class SwordUpgradeTest(SchemaUpgradeTest):
         Verify that if an exception is raised in an upgrader, the exception
         will be logged.
         """
-        playerID, swordID = self._testTwoObjectUpgrade()
+        choose(oldapp)
+        s = self.openStore()
+        swordID = oldapp.Sword(
+            store=s,
+            name=u'flaming vorpal doom',
+            hurtfulness=7).storeID
+        self.closeStore()
+
         choose(brokenapp)
         s = self.openStore()
         self.startStoreService()
@@ -253,7 +260,6 @@ class SwordUpgradeTest(SchemaUpgradeTest):
 
             loggedErrors = self.flushLoggedErrors(brokenapp.UpgradersAreBrokenHere)
             self.assertEqual(len(loggedErrors), 1)
-            originalError = loggedErrors[0]
 
             oldType = item.declareLegacyItem(
                 oldapp.Sword.typeName,
